#!/bin/bash
#
# dhcpd.sh			This module try to guess structure of LAN, and
#               create config file for DHCP server
# 
# Author: Jakub Krajniak <teodor at pld-linux.org>
# Licence: GPL
#
# $Id:$
#

detect_mac_address () {
	install_if_missing nmap
	show_message "$(nls "Scanning network, please wait")"
	nmap -sP -v "`echo $net_address | sed -e 's#\.0#\.\*#g'`" 2>/dev/null
	arp -na | grep -v incomplete | while read line; do
		ip_mac="`echo $line | cut -f2 -d' ' | sed -e 's/)//g; s/(//g'`"
		mac="`echo $line | cut -f4 -d' '`"
		echo "$ip_mac $mac" >> $MAC_FILE
	done
	$EDITOR $MAC_FILE
}

add_mac_address () {
	sed -ie "/^#.*/d;" $MAC_FILE
	if [ -s $MAC_FILE ]; then
		drop_section "host ranger" "}" ${CONF_FILE}
		OLDIFS="$IFS"
		IFS=$'\n'
		for line in `cat $MAC_FILE`; do
			let u++
			mac="`echo $line | cut -f2 -d' '`"
			ip="`echo $line | cut -f1 -d' '`"
			show_message "$mac -> $ip"
			cat >> ${CONF_FILE} << EOF 
host user$u {
	hardware ethernet $mac;
	fixed-address $ip;
}

EOF
		done
		IFS="$OLDIFS"
	fi
}

run_main () {
	install_if_missing dhcp
	cat ${CONF_FILE} | egrep "subnet.*$net_address.*netmask.*$netmask" && { show_message "Takie parametry sieci zostay ju zdefiniowane";} || {
	line_replace "ddns-update-style" "ddns-update-style      none;" ${CONF_FILE}
	cat << EOF >> ${CONF_FILE}
# network $net_address/$netmask
subnet $net_address netmask $netmask {
	default-lease-time $(($lease_time*60));
	range $ip_start $ip_stop;
	option domain-name-servers $dns_address;
	option domain-name "$domain";
	option routers $route_address;
	option subnet-mask $netmask;
	option broadcast-address $broadcast_address;
	option ntp-servers $ntp_address;
	option netbios-name-servers $smb_address;
}
EOF
	}
	add_mac_address
	/etc/rc.d/init.d/dhcpd restart || show_message "$(nls "There are some errors")";
}

detect_configuration () {
	[ -f "/etc/sysconfig/interfaces/ifcfg-eth0" ] && . /etc/sysconfig/interfaces/ifcfg-eth0;
	ip_address=`echo $IPADDR | cut -d\/ -f1`
	netmask=`ipcalc -m $ip_address | cut -f2 -d=`
	count_prefix "$netmask"
	net_address=`ipcalc -n $ip_address/$PREFIX | cut -f2 -d=`
	domain=`hostname -d`
	dns_address="`cat /etc/resolv.conf | egrep "^nameserver" | cut -f2 -d' ' | tail -1`"
	broadcast_address="`ipcalc -b $ip_address/$PREFIX | cut -f2 -d=`"
}



gui () {
	eval `dml<< EOF
	<meta title="$(nls "DHCP service configuration")"><br>
	$(nls "Network parametrs"): <br>
	$(nls "IP address"):      $ip_address<br>
	$(nls "Netmask"):         $netmask <br>
	$(nls "Network address"): $net_address<br>
	$(nls "Domain"):          $domain<br>
	-----------------------------------------------<br>
	$(nls "Address range"): <br>
	<input id=ip_start caption="\`echo $net_address|cut -f-3 -d.\`.2" width=16> - <input id=ip_stop caption="\`echo $net_address|cut -f-3 -d.\`.10" width=16><br><br>
	$(nls "Time server"): <input id=ntp_address caption=ntp.task.gda.pl><br>
	DNS:          <input id=dns_address caption="$dns_address,194.204.159.1" width=40><br>
	$(nls "SAMBA server"): <input id=smb_address caption=$ip_address><br>
	$(nls "Router"):       <input id=route_address caption=$ip_address><br>
	-----------------------------------------------<br>
	$(nls "Address IP timeout"): <input id=lease_time width=10 caption="10"> ($(nls "minutes"))<br>
	-----------------------------------------------<br>
	$(nls "Assign a fixed IP address to card's MAC address") <button id=edit_mac_list caption=$(nls "Edit")><br>
	<button id=clear_config caption="$(nls "Clear config")"><br>
	\`dml_buttons Ok Anuluj Pomoc Edytuj Przywr\`
EOF`

	[ "X$clear_config" = "Xyes" ] && { echo > /etc/dhcpd.conf; exec $0; }
	[ "X$edit_mac_list" = "Xyes" ] && { 
		echo -e "#File format\n#<ip address> <mac address>" > $MAC_FILE;
		detect_mac_address; 
		gui;
	}
	dml_cancel_check ${DATA_DIR}/NET/net_menu.sh
	dml_help_check ${DATA_DIR}/POMOC/README_dhcpd.txt
	dml_edit_check /etc/dhcpd.conf
	dml_recover_check ${CONF_DIR}/dhcpd.conf /etc/
	dml_check_the_rest ${DATA_DIR}/NET/net_menu.sh
}

MAC_FILE=`mktemp /tmp/pldconf.XXXXXX`;
CONF_FILE="/etc/dhcpd.conf"
backup_file ${CONF_FILE}
detect_configuration
gui
