#!/bin/bash
#GPL, mimooh at pld-linux.org

run_main()
{
	[ "X$poldek_shell" = "Xyes" ] && /usr/bin/poldek

	[ "X$sync" = "Xyes" ] && poldek --up || poldek --upa

	[ "X$inst_all" = "Xyes" ] && {
		edytory=yes; X=yes; desktop=yes; rox=yes; smb=yes; boot=yes
		net=yes; inne=yes; info=yes; devel=yes
	}
	[ "X$edytory" = "Xyes" ] && packets="$packets vim joe mc pico nano jed"

	[ "X$X" = "Xyes" ] && {
		packets="$packets X11 X11-fonts X11-fonts-ISO8859-2 X11-fonts-75dpi-ISO8859-2 X11-fonts-100dpi-ISO8859-2 X11-tools xinitrc"
		if [ "X$X_in" = "XX_nvidia" ]; then
			packets="$packets X11-driver-nvidia"
		else
			# too complicated for install_packets()
			poldek -Uv X11-driver* --ignore X11-driver-nvidia*
		fi
	}

	[ "X$desktop" = "Xyes" ] && packets="$packets WindowMaker icewm xfce4-panel xfwm4 xfce-utils xfce4-mixer fluxbox"

	[ "X$smb" = "Xyes" ] && packets="$packets samba samba-client smbc"

	[ "X$boot"  = "Xyes" ] && packets="$packets grub chkconfig"

	[ "X$net" = "Xyes" ] && packets="$packets rp-pppoe wvdial ppp ipchains"

	[ "X$printer" = "Xyes" ] && packets="$packets cups cups-clients"

	[ "X$inne" = "Xyes" ] && packets="$packets poink sudo rdate psmisc man info"

	[ "X$info" = "Xyes" ] && packets="$packets pciutils less nmap"

	[ "X$devel" = "Xyes" ] && packets="$packets kernel-headers autoconf automake gcc glibc-devel libstdc++-devel glibc-static"

	[ "X$poldek_fetch" = "Xyes" ] && poldek --shcmd="get $poldek_file_fetch"

	[ "$install_packets_command_line" ] && packets="$packets $install_packets_command_line"

	[ -n "$packets" ] && install_packets "$packets"
}

gui()
{
	eval `dml<< EOF
	<meta title="$(nls "Add/remove programs")" width=70><br>
 	<button id="poldek_conf" caption="$(nls "Setup")"> <button id="poldek_shell" caption="$(nls "Add/remove programs")"> <button id="sync" caption="$(nls "Synchronize index")"><br>
	------------------------------------------------------------------<br>
	$(nls "Install packages for sections below using poldek:")<br>
	<check id=edytory> $(nls "Editors") (vim/joe/mcedit/pico/nano/jed)<br>
	<menu id=x_driver hidden=1>
	<item id=X_normal> X11/fonts/all drivers
	<item id=X_nvidia> X11/fonts/nvidia driver
	</menu>
	<check id=X> X11: <input id=X_in menu=x_driver width=10 caption=X_normal><br>
	<check id=desktop> $(nls "Desktops") (xfwm4 & friends/wmaker/icewm/fluxbox)<br>
	<check id=boot> $(nls "System booting") (grub/chkconfig)<br>
	<check id=smb> $(nls "Network neighbourhood") (samba/samba-client/smbc)<br>
	<check id=net> $(nls "SDI/DSL/modem/firewall")<br>
	<check id=printer> $(nls "Printer") (cups)<br>
	<check id=inne> $(nls "Other") (sudo/rdate/psmisc/man/info/poink)<br>
	<check id=info> $(nls "About system") (pciutils/less/nmap)<br>
	<check id=devel> $(nls "Devel packages") (gcc & friends)<br>
	<check id=poldex> $(nls "Poldex (very nice frontend for poldek)")<br>
	<button id=instaluj caption="$(nls "Install selected")"> <button id=inst_all caption="$(nls "Install all")">
	<br><br><button id=poldek_fetch caption=$(nls "Download")> $(nls "package") <input id=poldek_file_fetch caption=coreutils width=16>.rpm
	<br>------------------------------------------------------------------<br>
	\`dml_buttons Anuluj Pomoc Wyjcie\`
EOF`

	[ "X$poldek_conf" = "Xyes" ] && exec ${DATA_DIR}/poldek_conf.sh
	if [ "X$poldek_shell" = "Xyes" ] || [ "X$sync" = "Xyes" ] || [ "X$instaluj" = "Xyes" ] \
		|| [ "X$inst_all" = "Xyes" ]  || [ "X$poldek_fetch" = "Xyes" ]; then
		dml_ok="yes"
	fi
	dml_cancel_check ${EXEC_PREFIX}/pldconf
	dml_help_check ${DATA_DIR}/POMOC/README_poldek.txt
	dml_check_the_rest ${EXEC_PREFIX}/pldconf
}

print_help()
{
	cat << EOF
$(nls "Options"):
-s   $(nls "synchronize index");
-a   $(nls "install all");
-e   $(nls "install editors");
-X   $(nls "install X section");
-N   $(nls "install original nvidia driver");
-d   $(nls "install Desktop section");
-S   $(nls "install SAMBA section");
-b   $(nls "install Boot section");
-n   $(nls "install Network section");
-p   $(nls "install Printer section");
-I   $(nls "install Other section");
-o   $(nls "install About system section");
-c   $(nls "install devel packages");
-i   $(nls "install packages from command line. Use quotation if you install
more than one package eg.") -i "rox mozilla gimp"
-f <$(nls "package")>  $(nls "download packages to current directory");
-h   $(nls "help");
$(nls "no options run GUI")
EOF
}

while getopts "saeXNdSbnpIoci:f:h" opt
do
	case $opt in
		s ) sync="yes";;
		a ) inst_all="yes";;
		e ) edytory="yes";;
		X ) X="yes";;
		N ) X_in="X_nvidia"; X="yes";;
		d ) desktop="yes";;
		S ) smb="yes";;
		b ) boot="yes";;
		n ) net="yes";;
		p ) printer="yes";;
		I ) inne="yes";;
		o ) info="yes";;
		c ) devel="yes";;
		i ) install_packets_command_line="$OPTARG";;
		f ) poldek_file_fetch=$OPTARG; poldek_fetch="yes";;
		h ) print_help; exit;; 
		? ) print_help; exit;; 
	esac
done

[ -z "$1" ] && gui || run_main 2>/dev/null
